Imports DotNetNuke.Framework.Providers
Imports DotNetNuke.Common.Utilities
Imports DotNetNuke.Common.Utilities.Config
Imports System.StringComparer
Imports System.Data
Imports System.Data.SqlClient
Public Class FeatureController
#Region "Methods"
    Public Sub New()
        Dim provider As Provider = CType(Me._providerConfiguration.Providers.Item(Me._providerConfiguration.DefaultProvider), Provider)
        Me._objectQualifier = provider.Attributes.Item("objectQualifier")
        If (Me._objectQualifier <> String.Empty And Not Me._objectQualifier.EndsWith("_")) Then
            Me._objectQualifier = (Me._objectQualifier & "_")
        End If
        Me._databaseOwner = provider.Attributes.Item("databaseOwner")
        If (Me._databaseOwner <> String.Empty And Not Me._databaseOwner.EndsWith(".")) Then
            Me._databaseOwner = (Me._databaseOwner & ".")
        End If
    End Sub

    Public Sub DeleteFeature(ByVal FeatureId As Integer)
        Try
            Dim connection As New SqlConnection(Me.ConnectionString)
            Dim command As New SqlCommand(DatabaseOwner & ObjectQualifier & "activeapc_dnn_Features_Delete", connection)
            command.CommandType = CommandType.StoredProcedure
            command.Parameters.Add("@FeatureId", SqlDbType.Int).Value = FeatureId
            connection.Open()
            command.ExecuteNonQuery()
            connection.Close()
        Catch ex As Exception

        End Try
    End Sub

    Public Function GetFeature(ByVal FeatureId As Integer) As FeatureInfo
        Try
            Dim fi As New FeatureInfo
            Dim connection As New SqlConnection(Me.ConnectionString)
            Dim command As New SqlCommand(DatabaseOwner & ObjectQualifier & "activeapc_dnn_Features_GetByFeatureId", connection)
            command.CommandType = CommandType.StoredProcedure
            command.Parameters.Add("@FeatureId", SqlDbType.Int).Value = FeatureId
            connection.Open()
            Dim reader As IDataReader = command.ExecuteReader(CommandBehavior.CloseConnection)
            Do While reader.Read
                fi.Feature = Convert.ToString((reader.Item("Feature")))
                fi.Comment = Convert.ToString((reader.Item("Comment")))
                fi.SortOrder = Convert.ToInt32((reader.Item("SortOrder")))
                fi.FeatureGroupId = Convert.ToInt32((reader.Item("FeatureGroupId")))
                fi.FeatureId = FeatureId
            Loop
            reader.Close()
            reader.Dispose()
            command.Dispose()
            Return fi
        Catch ex As Exception
            Return Nothing
        End Try
    End Function

    Public Function GetFeatures(ByVal FeatureGroupId As Integer) As IDataReader
        Try
            Dim connection As New SqlConnection(Me.ConnectionString)
            Dim command As New SqlCommand(DatabaseOwner & ObjectQualifier & "activeapc_dnn_Features_GetByFeatureGroupId", connection)
            command.CommandType = CommandType.StoredProcedure
            command.Parameters.Add("@FeatureGroupId", SqlDbType.Int).Value = FeatureGroupId
            connection.Open()
            Return command.ExecuteReader(CommandBehavior.CloseConnection)
        Catch ex As Exception
            Return Nothing
        End Try
    End Function

    Private Function GetNull(ByVal Field As Object) As Object
        Return Null.GetNull((Field), DBNull.Value)
    End Function

    Public Function SaveFeature(ByVal feature As FeatureInfo) As Integer
        Try
            Dim connection As New SqlConnection(Me.ConnectionString)
            Dim command As New SqlCommand(DatabaseOwner & ObjectQualifier & "activeapc_dnn_Features_Save", connection)
            command.CommandType = CommandType.StoredProcedure
            Dim parameters As SqlParameterCollection = command.Parameters
            parameters.Add("@FeatureId", SqlDbType.Int).Value = feature.FeatureId
            parameters.Add("@FeatureGroupId", SqlDbType.Int).Value = feature.FeatureGroupId
            parameters.Add("@Feature", SqlDbType.NVarChar, &HFA0).Value = feature.Feature
            parameters.Add("@Comment", SqlDbType.NVarChar, &HFA0).Value = feature.Comment
            parameters.Add("@SortOrder", SqlDbType.Int).Value = feature.SortOrder
            parameters = Nothing
            connection.Open()
            feature.FeatureId = CInt(command.ExecuteScalar)
            connection.Close()
            command.Dispose()
            connection.Dispose()
            Return feature.FeatureId
        Catch ex As Exception
            Return Nothing
        End Try
    End Function

    Public Function SaveFeatureSortOrder(ByVal FeatureId As Integer, ByVal NewPosition As Integer, ByVal OldPosition As Integer) As Boolean
        Try
            Dim connection As New SqlConnection(Me.ConnectionString)
            Dim command As New SqlCommand(DatabaseOwner & ObjectQualifier & "activeapc_dnn_Features_SaveSortOrder", connection)
            command.CommandType = CommandType.StoredProcedure
            command.Parameters.Add("@FeatureId", SqlDbType.Int).Value = FeatureId
            command.Parameters.Add("@SortOrder", SqlDbType.Int).Value = NewPosition
            command.Parameters.Add("@OldSortOrder", SqlDbType.Int).Value = OldPosition
            connection.Open()
            command.ExecuteNonQuery()
            connection.Close()
            Return True
        Catch ex As Exception
            Return False
        End Try
    End Function
#End Region

#Region "Public Properties"
    Public ReadOnly Property ConnectionString() As String
        Get
            Return Me._connectionString
        End Get
    End Property

    Public ReadOnly Property DatabaseOwner() As String
        Get
            Return Me._databaseOwner
        End Get
    End Property

    Public ReadOnly Property ObjectQualifier() As String
        Get
            Return Me._objectQualifier
        End Get
    End Property
#End Region

#Region "Private Members"
    Private _connectionString As String = Config.GetConnectionString
    Private _databaseOwner As String
    Private _objectQualifier As String
    Private _providerConfiguration As ProviderConfiguration = ProviderConfiguration.GetProviderConfiguration("data")
    Private Const ProviderType As String = "data"
#End Region
End Class